package com.ruoyi.business.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.business.mapper.HwFenceTargetMapper;
import com.ruoyi.business.domain.HwFenceTarget;
import com.ruoyi.business.service.IHwFenceTargetService;

/**
 * 电子围栏目标Service业务层处理
 * 
 * @author xins
 * @date 2023-09-04
 */
@Service
public class HwFenceTargetServiceImpl implements IHwFenceTargetService 
{
    @Autowired
    private HwFenceTargetMapper hwFenceTargetMapper;

    /**
     * 查询电子围栏目标
     * 
     * @param targetId 电子围栏目标主键
     * @return 电子围栏目标
     */
    @Override
    public HwFenceTarget selectHwFenceTargetByTargetId(Long targetId)
    {
        return hwFenceTargetMapper.selectHwFenceTargetByTargetId(targetId);
    }

    /**
     * 查询电子围栏目标列表
     * 
     * @param hwFenceTarget 电子围栏目标
     * @return 电子围栏目标
     */
    @Override
    public List<HwFenceTarget> selectHwFenceTargetList(HwFenceTarget hwFenceTarget)
    {
        return hwFenceTargetMapper.selectHwFenceTargetList(hwFenceTarget);
    }

    /**
     * 新增电子围栏目标
     * 
     * @param hwFenceTarget 电子围栏目标
     * @return 结果
     */
    @Override
    public int insertHwFenceTarget(HwFenceTarget hwFenceTarget)
    {
        return hwFenceTargetMapper.insertHwFenceTarget(hwFenceTarget);
    }

    /**
     * 修改电子围栏目标
     * 
     * @param hwFenceTarget 电子围栏目标
     * @return 结果
     */
    @Override
    public int updateHwFenceTarget(HwFenceTarget hwFenceTarget)
    {
        return hwFenceTargetMapper.updateHwFenceTarget(hwFenceTarget);
    }

    /**
     * 批量删除电子围栏目标
     * 
     * @param targetIds 需要删除的电子围栏目标主键
     * @return 结果
     */
    @Override
    public int deleteHwFenceTargetByTargetIds(Long[] targetIds)
    {
        return hwFenceTargetMapper.deleteHwFenceTargetByTargetIds(targetIds);
    }

    /**
     * 删除电子围栏目标信息
     * 
     * @param targetId 电子围栏目标主键
     * @return 结果
     */
    @Override
    public int deleteHwFenceTargetByTargetId(Long targetId)
    {
        return hwFenceTargetMapper.deleteHwFenceTargetByTargetId(targetId);
    }
}
